@@ -47,7 +47,6 @@ import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
 import com.sencha.gxt.widget.core.client.form.ComboBox;
 import com.sencha.gxt.widget.core.client.form.FieldLabel;
 import com.sencha.gxt.widget.core.client.form.TextField;
-import com.sencha.gxt.widget.core.client.info.Info;
 
 /**
  * This Panel is used only with Codelist,
@@ -58,30 +57,31 @@ import com.sencha.gxt.widget.core.client.info.Info;
  * 
  */
 public class CreateDefColumnPanel extends FramedPanel {
-	protected static final String WIDTH = "448px";
-	protected static final String HEIGHT = "180px";
-	protected static final String FIELDWIDTH = "436px";
-	protected static final String FIELDSHEIGHT = "130px";
+	private static final String WIDTH = "448px";
+	private static final String HEIGHT = "180px";
+	private static final String FIELDWIDTH = "436px";
+	private static final String FIELDSHEIGHT = "130px";
 
-	protected ArrayList<CreateDefColumnListener> listeners;
+	private ArrayList<CreateDefColumnListener> listeners;
 
-	protected EventBus eventBus;
-	protected CreateDefColumnDialog parent;
-	protected TableType tableType;
+	private EventBus eventBus;
+	private CreateDefColumnDialog parent;
+	private TableType tableType;
 
-	protected ComboBox<ColumnTypeCodeElement> comboColumnTypeCode = null;
-	protected FieldLabel comboColumnTypeCodeLabel;
+	private ComboBox<ColumnTypeCodeElement> comboColumnTypeCode = null;
+	private FieldLabel comboColumnTypeCodeLabel;
 
-	protected ComboBox<LocaleTypeElement> comboLocaleType = null;
-	protected FieldLabel comboLocaleTypeLabel;
-	protected ListStore<LocaleTypeElement> storeComboLocaleType;
+	private ComboBox<LocaleTypeElement> comboLocaleType = null;
+	private FieldLabel comboLocaleTypeLabel;
+	private ListStore<LocaleTypeElement> storeComboLocaleType;
 
 	private TextButton btnSave;
 	private TextButton btnClose;
 	private SimpleContainer form;
 	private VerticalLayoutContainer formLayout;
-	private TextField label;
+	private TextField columnLabel;
 	private TextField defaultValue;
+	private CreateDefColumnMessages msgs;
 
 	/**
 	 * 
@@ -96,10 +96,15 @@ public class CreateDefColumnPanel extends FramedPanel {
 		this.parent = parent;
 		this.eventBus = eventBus;
 		this.tableType = tableType;
+		initMessages();
 		initListeners();
 		init();
 		create();
 	}
+	
+	protected void initMessages(){
+		msgs = GWT.create(CreateDefColumnMessages.class);
+	}
 
 	protected void init() {
 		setWidth(WIDTH);
@@ -114,13 +119,13 @@ public class CreateDefColumnPanel extends FramedPanel {
 
 	protected void create() {
 		// Label
-		label = new TextField();
-		FieldLabel nameLabel = new FieldLabel(label, "Column Label");
+		columnLabel = new TextField();
+		FieldLabel columnLabelLabel = new FieldLabel(columnLabel, msgs.columnLabel());
 
 		// Default Value
 		defaultValue = new TextField();
 		FieldLabel defaultValueLabel = new FieldLabel(defaultValue,
-				"Default Value");
+				msgs.defaultValueLabel());
 
 		// comboColumnTypeCode
 		ColumnTypeCodeProperties propsColumnTypeCode = GWT
@@ -152,14 +157,14 @@ public class CreateDefColumnPanel extends FramedPanel {
 
 		addHandlersForComboColumnTypeCode(propsColumnTypeCode.label());
 
-		comboColumnTypeCode.setEmptyText("Select a column type...");
+		comboColumnTypeCode.setEmptyText(msgs.comboColumnTypeCodeEmptyText());
 		comboColumnTypeCode.setWidth(191);
 		comboColumnTypeCode.setEditable(false);
 		comboColumnTypeCode.setTypeAhead(false);
 		comboColumnTypeCode.setTriggerAction(TriggerAction.ALL);
 
 		comboColumnTypeCodeLabel = new FieldLabel(comboColumnTypeCode,
-				"Column Type");
+				msgs.comboColumnTypeCodeLabel());
 
 		// comboLocaleType
 		LocaleTypeProperties propsLocaleType = GWT
@@ -183,12 +188,12 @@ public class CreateDefColumnPanel extends FramedPanel {
 
 		addHandlersForComboLocaleType(propsLocaleType.label());
 
-		comboLocaleType.setEmptyText("Select a locale type...");
+		comboLocaleType.setEmptyText(msgs.comboLocaleTypeEmptyText());
 		comboLocaleType.setWidth(191);
 		comboLocaleType.setTypeAhead(true);
 		comboLocaleType.setTriggerAction(TriggerAction.ALL);
 
-		comboLocaleTypeLabel = new FieldLabel(comboLocaleType, "Locale");
+		comboLocaleTypeLabel = new FieldLabel(comboLocaleType, msgs.comboLocaleTypeLabel());
 
 		//
 		form = new SimpleContainer();
@@ -199,7 +204,7 @@ public class CreateDefColumnPanel extends FramedPanel {
 		formLayout.setScrollMode(ScrollMode.AUTO);
 
 		formLayout
-				.add(nameLabel, new VerticalLayoutData(1, -1, new Margins(0)));
+				.add(columnLabelLabel, new VerticalLayoutData(1, -1, new Margins(0)));
 		formLayout.add(comboColumnTypeCodeLabel, new VerticalLayoutData(1, -1,
 				new Margins(0)));
 		formLayout.add(comboLocaleTypeLabel, new VerticalLayoutData(1, -1,
@@ -209,10 +214,10 @@ public class CreateDefColumnPanel extends FramedPanel {
 
 		form.add(formLayout);
 
-		btnSave = new TextButton("Save");
+		btnSave = new TextButton(msgs.btnSaveText());
 		btnSave.setIcon(ResourceBundle.INSTANCE.save());
 		btnSave.setIconAlign(IconAlign.RIGHT);
-		btnSave.setToolTip("Save");
+		btnSave.setToolTip(msgs.btnSaveToolTip());
 		btnSave.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -223,10 +228,10 @@ public class CreateDefColumnPanel extends FramedPanel {
 			}
 		});
 
-		btnClose = new TextButton("Close");
+		btnClose = new TextButton(msgs.btnCloseText());
 		btnClose.setIcon(ResourceBundle.INSTANCE.close());
 		btnClose.setIconAlign(IconAlign.RIGHT);
-		btnClose.setToolTip("Close");
+		btnClose.setToolTip(msgs.btnCloseToolTip());
 		btnClose.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -257,7 +262,7 @@ public class CreateDefColumnPanel extends FramedPanel {
 		ColumnTypeCode currentType = null;
 		String localeName = null;
 
-		String lab = label.getCurrentValue();
+		String lab = columnLabel.getCurrentValue();
 		ColumnTypeCodeElement typeElement = comboColumnTypeCode
 				.getCurrentValue();
 		LocaleTypeElement localeElement = comboLocaleType.getCurrentValue();
@@ -266,18 +271,18 @@ public class CreateDefColumnPanel extends FramedPanel {
 		Log.debug("CheckValue: label: " + lab + ", type: " + typeElement
 				+ ", locale: " + localeElement + ", default: " + valueDefault);
 		if (lab == null || lab.isEmpty()) {
-			UtilsGXT3.alert("Attention", "Add a label");
+			UtilsGXT3.alert("Attention", msgs.addALabel());
 			btnSave.enable();
 			return;
 		}
 
 		if (typeElement == null) {
-			UtilsGXT3.alert("Attention", "No type selected");
+			UtilsGXT3.alert("Attention", msgs.noTypeSelected());
 			btnSave.enable();
 			return;
 		} else {
 			if (typeElement.getCode() == null) {
-				UtilsGXT3.alert("Attention", "No type selected");
+				UtilsGXT3.alert("Attention", msgs.noTypeSelected());
 				btnSave.enable();
 				return;
 			} else {
@@ -297,13 +302,13 @@ public class CreateDefColumnPanel extends FramedPanel {
 			break;
 		case CODENAME:
 			if (localeElement == null) {
-				UtilsGXT3.alert("Attention", "No locale selected");
+				UtilsGXT3.alert("Attention", msgs.noLocaleSelected());
 				btnSave.enable();
 				return;
 			} else {
 				if (localeElement.getLocaleName() == null
 						|| localeElement.getLocaleName().isEmpty()) {
-					UtilsGXT3.alert("Attention", "No locale selected");
+					UtilsGXT3.alert("Attention", msgs.noLocaleSelected());
 					btnSave.enable();
 					return;
 				} else {
@@ -340,13 +345,6 @@ public class CreateDefColumnPanel extends FramedPanel {
 				.addSelectionHandler(new SelectionHandler<ColumnTypeCodeElement>() {
 					public void onSelection(
 							SelectionEvent<ColumnTypeCodeElement> event) {
-						Info.display(
-								"Column Type Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboColumnTypeCode selected: "
 								+ event.getSelectedItem());
 						ColumnTypeCodeElement columnType = event
@@ -363,13 +361,6 @@ public class CreateDefColumnPanel extends FramedPanel {
 				.addSelectionHandler(new SelectionHandler<LocaleTypeElement>() {
 					public void onSelection(
 							SelectionEvent<LocaleTypeElement> event) {
-						Info.display(
-								"Locale Type Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboLocaleType selected: "
 								+ event.getSelectedItem());
 						LocaleTypeElement localeType = event.getSelectedItem();
@@ -418,7 +409,7 @@ public class CreateDefColumnPanel extends FramedPanel {
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error retrieving locales",
+									UtilsGXT3.alert(msgs.errorRetrievingLocaleHead(),
 											caught.getLocalizedMessage());
 								}
 							}
